Struct esp32_simple::light::Led

source ·
pub struct Led<'a> { /* private fields */ }
Represents an LED with color and state control.

Type Parameters

  • 'a - Lifetime of the LED.

Implementations

source

impl<'a> Led<'a>

source

pub fn new(tx_rmt: TxRmtDriver<'a>) -> Result<Self>

Creates a new Led instance.

Arguments
  • tx_rmt - A TxRmtDriver for controlling the LED.
Returns

A new Led initialized to off with black color.

Errors

Returns an error if the LED cannot be initialized.

source

pub fn set_color(&mut self, color: Rgb) -> Result<()>

Sets the color of the LED.

Arguments
  • color - The new color for the LED.
Returns

Ok(()) on success.

Errors

Returns an error if the color cannot be applied.

source

pub fn on(&mut self) -> Result<()>

Turns on the LED.

Returns

Ok(()) on success.

Errors

Returns an error if the LED cannot be turned on.

source

pub fn off(&mut self) -> Result<()>

Turns off the LED.

Returns

Ok(()) on success.

Errors

Returns an error if the LED cannot be turned off.