pub struct Led<'a> { /* private fields */ }
Represents an LED with color and state control.
'a
Creates a new Led instance.
Led
tx_rmt
TxRmtDriver
A new Led initialized to off with black color.
Returns an error if the LED cannot be initialized.
Sets the color of the LED.
color
Ok(()) on success.
Ok(())
Returns an error if the color cannot be applied.
Turns on the LED.
Returns an error if the LED cannot be turned on.
Turns off the LED.
Returns an error if the LED cannot be turned off.
Toggles the state of the LED.
Returns an error if the LED state cannot be toggled.
TypeId
self
Returns the argument unchanged.
Calls U::from(self).
U::from(self)
That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.
[From]<T> for U